export interface Encoder {
    stringify(wordArray: WordArray): string;
    parse(str: string): WordArray;
}
export interface WordArray {
    words: number[];
    sigBytes: number;
    toString(encoder?: Encoder): string;
    concat(wordArray: WordArray): this;
    clamp(): void;
    clone(): WordArray;
}
export interface Hasher {
    reset(): void;
    update(messageUpdate: WordArray | string): this;
    finalize(messageUpdate?: WordArray | string): WordArray;
}
export interface IUseHashFileReturn {
    isHashLoading: boolean;
    isHashError: boolean;
    sha256: string | null;
    sha1: string | null;
    md5: string | null;
    timeSpend: number | null;
}
/**
 * hash file
 * @param file the file need to hash
 * @param hashAlgo hash algorithm 'md5' |'sha1'| 'sha256'  default:sha256
 * @param chunkSizeCustom   chunk size default:10M
 * @return IUseHashFileReturn
 */
export declare const useHashFileCode: (file: File | null, hashAlgo?: "md5" | "sha1" | "sha256" | undefined, chunkSizeCustom?: number | undefined) => IUseHashFileReturn;
