'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var react = require('react');
var CryptoJs = _interopDefault(require('crypto-js'));
var encHex = _interopDefault(require('crypto-js/enc-hex'));

/**
 * hash file
 * @param file the file need to hash
 * @param hashAlgo hash algorithm 'md5' |'sha1'| 'sha256'  default:sha256
 * @param chunkSizeCustom   chunk size default:10M
 * @return IUseHashFileReturn
 */

var useHashFileCode = function useHashFileCode(file, hashAlgo, chunkSizeCustom) {
  var startTimeRef = react.useRef(null);

  var _useState = react.useState(true),
      isHashLoading = _useState[0],
      setIsHashLoading = _useState[1];

  var _useState2 = react.useState(false),
      isHashError = _useState2[0],
      setIsHashError = _useState2[1];

  var _useState3 = react.useState(null),
      sha256 = _useState3[0],
      setSha256 = _useState3[1];

  var _useState4 = react.useState(null),
      sha1 = _useState4[0],
      setSha1 = _useState4[1];

  var _useState5 = react.useState(null),
      md5 = _useState5[0],
      setMd5 = _useState5[1];

  var _useState6 = react.useState(null),
      timeSpend = _useState6[0],
      setTimeSpend = _useState6[1];

  react.useEffect(function () {
    if (!file) return;
    /* record start time */

    startTimeRef.current = Date.now();

    var hashFileInternal = function hashFileInternal(file, alog) {
      var chunkSize = 1024 * 1024 * 10;
      /* custom chunk size */

      if (chunkSizeCustom) {
        chunkSize = chunkSizeCustom;
      }

      var promise = Promise.resolve();

      var _loop = function _loop(index) {
        promise = promise.then(function () {
          return hashBlob(file.slice(index, index + chunkSize));
        });
      };

      for (var index = 0; index < file.size; index += chunkSize) {
        _loop(index);
      }
      /* arraybuffer to word array */


      function arrayBufferToWordArray(ab) {
        var i8a = new Uint8Array(ab);
        var a = [];

        for (var i = 0; i < i8a.length; i += 4) {
          a.push(i8a[i] << 24 | i8a[i + 1] << 16 | i8a[i + 2] << 8 | i8a[i + 3]);
        }

        return CryptoJs.lib.WordArray.create(a, i8a.length);
      }
      /* hash blob */


      var hashBlob = function hashBlob(blob) {
        return new Promise(function (resolve) {
          var reader = new FileReader();

          reader.onload = function (_ref) {
            var target = _ref.target;
            if (!target.result) return;
            if (typeof target.result === 'string') return;
            var wordArray = arrayBufferToWordArray(target.result); // update hash

            alog.update(wordArray);
            resolve();
          };

          reader.readAsArrayBuffer(blob);
        });
      };

      return promise.then(function () {
        return encHex.stringify(alog.finalize());
      });
    };

    var hashFileSha256 = function hashFileSha256() {
      hashFileInternal(file, CryptoJs.algo.SHA256.create()).then(function (sha256) {
        setSha256(sha256);

        if (startTimeRef.current) {
          var t = Date.now() - startTimeRef.current;
          setTimeSpend(t);
        }
      })["catch"](function () {
        setIsHashError(true);
        setIsHashLoading(false);
      });
    };
    /* chose algo */


    switch (hashAlgo) {
      case 'md5':
        hashFileInternal(file, CryptoJs.algo.MD5.create()).then(function (md5) {
          setMd5(md5);

          if (startTimeRef.current) {
            var t = Date.now() - startTimeRef.current;
            setTimeSpend(t);
          }
        })["catch"](function () {
          setIsHashError(true);
          setIsHashLoading(false);
        });
        break;

      case 'sha1':
        hashFileInternal(file, CryptoJs.algo.SHA1.create()).then(function (sha1) {
          setSha1(sha1);

          if (startTimeRef.current) {
            var t = Date.now() - startTimeRef.current;
            setTimeSpend(t);
          }
        })["catch"](function () {
          setIsHashError(true);
          setIsHashLoading(false);
        });
        break;

      case 'sha256':
        hashFileSha256();
        break;

      default:
        hashFileSha256();
    }
  }, [chunkSizeCustom, file, hashAlgo]);
  return {
    isHashLoading: isHashLoading,
    isHashError: isHashError,
    sha256: sha256,
    sha1: sha1,
    md5: md5,
    timeSpend: timeSpend
  };
};

exports.useHashFileCode = useHashFileCode;
//# sourceMappingURL=use-hashcode.cjs.development.js.map
